searchData={"items":[{"type":"module","title":"Geometry","doc":"A set of geometry types for\n[WKT](https://en.wikipedia.org/wiki/Well-known_text_representation_of_geometry)/\n[WKB](https://en.wikipedia.org/wiki/Well-known_text_representation_of_geometry#Well-known_binary)\nand [GeoJson](https://geojson.org/).\n\n`Geometry` provide the decoding and encoding for geometires of type WKT/EWKT,\nWKB/EWKB and GeoJon.\n\nThe following gemetries are supported:\n+ Point\n  + `Geometry.Point`, `Geometry.PointM`, `Geometry.PointZ`, `Geometry.PointZM`\n+ LineString\n  + `Geometry.LineString`, `Geometry.LineStringM`, `Geometry.LineStringZ`,\n    `Geometry.LineStringZM`\n+ Polygon\n  + `Geometry.Polygon`, `Geometry.PolygonM`, `Geometry.PolygonZ`,\n    `Geometry.PolygonZM`\n+ MultiPoint\n  + `Geometry.MultiPoint`, `Geometry.MultiPointM`, `Geometry.MultiPointZ`,\n    `Geometry.MultiPointZM`\n+ MultiLineString\n  + `Geometry.MultiLineString`, `Geometry.MultiLineStringM`,\n    `Geometry.MultiLineStringZ`, `Geometry.MultiLineStringZM`\n+ MultiPolyogon\n  + `Geometry.MultiPolygon`, `Geometry.MultiPolygonM`,\n    `Geometry.MultiPolygonZ`, `Geometry.MultiPolygonZM`\n+ GeometryCollection\n  + `Geometry.GeometryCollection`, `Geometry.GeometryCollectionM`,\n    `Geometry.GeometryCollectionZ`, `Geometry.GeometryCollectionZM`\n\nFor GeoJson also `Geometry.Feature` and `Geometry.FeatureCollection` are\nsupported.","ref":"Geometry.html"},{"type":"type","title":"Geometry.coordinates/0","doc":"An n-dimensional point.","ref":"Geometry.html#t:coordinates/0"},{"type":"function","title":"Geometry.empty?/1","doc":"Returns true if a geometry is empty.","ref":"Geometry.html#empty?/1"},{"type":"function","title":"Examples - Geometry.empty?/1","doc":"iex> Geometry.empty?(Point.new(1, 2))\n    false\n    iex> Geometry.empty?(Point.new())\n    true\n    iex> Geometry.empty?(LineString.new([]))\n    true","ref":"Geometry.html#empty?/1-examples"},{"type":"type","title":"Geometry.endian/0","doc":"Byte order.\n\n- `:ndr`: Little endian byte order encoding\n- `:xdr`: Big endian byte order encoding","ref":"Geometry.html#t:endian/0"},{"type":"function","title":"Geometry.from_ewkb/1","doc":"Returns an `:ok` tuple with the geometry from the given EWKB binary.\n\nOtherwise returns an `:error` tuple.\n\nIf the given binary not an extended `t:wkb/0` a nil for the SRID is returned.","ref":"Geometry.html#from_ewkb/1"},{"type":"function","title":"Examples - Geometry.from_ewkb/1","doc":"iex> \"0020000001000012673FF00000000000004000000000000000\"\n    ...> |> Base.decode16!()\n    ...> |> Geometry.from_ewkb()\n    {:ok, %Point{coordinates: [1.0, 2.0], srid: 4711}}\n\n    iex> \"0101000080000000000000F03F00000000000000400000000000000840\"\n    ...> |> Base.decode16!()\n    ...> |> Geometry.from_ewkb()\n    {:ok, %PointZ{coordinates: [1.0, 2.0, 3.0], srid: 0}}","ref":"Geometry.html#from_ewkb/1-examples"},{"type":"function","title":"Geometry.from_ewkb!/1","doc":"The same as `from_ewkb/1`, but raises a `Geometry.DecodeError` exception if it fails.","ref":"Geometry.html#from_ewkb!/1"},{"type":"function","title":"Geometry.from_ewkt/1","doc":"Returns an `:ok` tuple with the geometry from the given EWKT string.\n\nOtherwise returns an `:error` tuple.\n\nIf the given string not an extended `t:wkt/0` a nil for the SRID is returned.","ref":"Geometry.html#from_ewkt/1"},{"type":"function","title":"Examples - Geometry.from_ewkt/1","doc":"iex> Geometry.from_ewkt(\"SRID=42;Point (1.1 2.2)\")\n    {:ok, %Point{coordinates: [1.1, 2.2], srid: 42}}\n\n    iex> Geometry.from_ewkt(\"Point ZM (1 2 3 4)\")\n    {:ok, %PointZM{coordinates: [1, 2, 3, 4], srid: 0}}\n\n    iex> Geometry.from_ewkt(\"Point XY (1 2 3 4)\")\n    {:error, \"expected Point data\", \"XY (1 2 3 4)\", {1, 0}, 6}\n    {\n      :error,\n      %Geometry.DecodeError{\n        from: :wkt,\n        line: {1, 0},\n        message: \"expected Point data\",\n        offset: 6,\n        rest: \"XY (1 2 3 4)\"\n      }\n    }","ref":"Geometry.html#from_ewkt/1-examples"},{"type":"function","title":"Geometry.from_ewkt!/1","doc":"The same as `from_ewkt/1`, but raises a `Geometry.DecodeError` exception if it fails.","ref":"Geometry.html#from_ewkt!/1"},{"type":"function","title":"Geometry.from_geo_json/2","doc":"Returns an `:ok` tuple with the geometry from the given GeoJSON term.\n\nOtherwise returns an `:error` tuple.\n\nThe optional second argument specifies which type is expected. The\npossible values are `:xy`, `:xym`, `xyz`, and `:xyzm`. Defaults to `:xy`.","ref":"Geometry.html#from_geo_json/2"},{"type":"function","title":"Examples - Geometry.from_geo_json/2","doc":"iex> ~s({\"type\": \"Point\", \"coordinates\": [1, 2]})\n    iex> |> Jason.decode!()\n    iex> |> Geometry.from_geo_json()\n    {:ok, %Point{coordinates: [1, 2], srid: 4326}}\n\n    iex> ~s({\"type\": \"Point\", \"coordinates\": [1, 2, 3, 4]})\n    iex> |> Jason.decode!()\n    iex> |> Geometry.from_geo_json(:xyzm)\n    {:ok, %PointZM{coordinates: [1, 2, 3, 4], srid: 4326}}\n\n    iex> ~s({\"type\": \"Dot\", \"coordinates\": [1, 2]})\n    iex> |> Jason.decode!()\n    iex> |> Geometry.from_geo_json()\n    {\n      :error,\n      %Geometry.DecodeError{\n        from: :geo_json,\n        reason: [unknown_type: \"Dot\"]\n      }\n    }","ref":"Geometry.html#from_geo_json/2-examples"},{"type":"function","title":"Geometry.from_geo_json!/2","doc":"The same as `from_geo_json/1`, but raises a `Geometry.DecodeError` exception if it\nfails.","ref":"Geometry.html#from_geo_json!/2"},{"type":"function","title":"Geometry.from_wkb/1","doc":"Returns an `:ok` tuple with the geometry from the given WKB binary.\n\nOtherwise returns an `:error` tuple.\n\nIf the given binary is an extended `t:wkb/0` the SRID is ignored.","ref":"Geometry.html#from_wkb/1"},{"type":"function","title":"Examples - Geometry.from_wkb/1","doc":"iex> \"0020000001000012673FF00000000000004000000000000000\"\n    ...> |> Base.decode16!()\n    ...> |> Geometry.from_wkb()\n    {:ok, %Point{coordinates: [1.0, 2.0], srid: 4711}}\n\n    iex> \"0101000080000000000000F03F00000000000000400000000000000840\"\n    ...> |> Base.decode16!()\n    ...> |> Geometry.from_wkb()\n    {:ok, %PointZ{coordinates: [1.0, 2.0, 3.0]}}\n\n    iex> \"FF\"\n    ...> |> Base.decode16!()\n    ...> |> Geometry.from_wkb()\n    {\n      :error,\n      %Geometry.DecodeError{\n        from: :wkb,\n        offset: 0,\n        reason: [expected_endian: :flag],\n        rest: <<255>>\n      }\n    }","ref":"Geometry.html#from_wkb/1-examples"},{"type":"function","title":"Geometry.from_wkb!/1","doc":"The same as `from_wkb/1`, but raises a `Geometry.DecodeError` exception if it fails.","ref":"Geometry.html#from_wkb!/1"},{"type":"function","title":"Geometry.from_wkt/1","doc":"Returns an `:ok` tuple with the geometry from the given WKT string.\n\nOtherwise returns an `:error` tuple.\n\nIf the given string is an extended `t:wkt/0` the SRID is ignored.","ref":"Geometry.html#from_wkt/1"},{"type":"function","title":"Examples - Geometry.from_wkt/1","doc":"iex> Geometry.from_wkt(\"SRID=42;Point (1.1 2.2)\")\n    {:ok, %Point{coordinates: [1.1, 2.2], srid: 42}}\n\n    iex> Geometry.from_wkt(\"Point ZM (1 2 3 4)\")\n    {:ok, %PointZM{coordinates: [1, 2, 3, 4], srid: 0}}\n\n    iex> Geometry.from_wkt(\"Point XY (1 2 3 4)\")\n    {:error,  %Geometry.DecodeError{\n      from: :wkt,\n      line: {1, 0},\n      message: \"expected Point data\",\n      offset: 6,\n      rest: \"XY (1 2 3 4)\"}\n    }","ref":"Geometry.html#from_wkt/1-examples"},{"type":"function","title":"Geometry.from_wkt!/1","doc":"The same as `from_wkt/1`, but raises a `Geometry.DecodeError` exception if it fails.","ref":"Geometry.html#from_wkt!/1"},{"type":"type","title":"Geometry.geo_json_term/0","doc":"A [GeoJson](https://geojson.org) term.","ref":"Geometry.html#t:geo_json_term/0"},{"type":"type","title":"Geometry.path/0","doc":"A list of n-dimensional coordinates.","ref":"Geometry.html#t:path/0"},{"type":"type","title":"Geometry.ring/0","doc":"A list of n-dimensional coordinates where the first and last point are equal, creating a ring.","ref":"Geometry.html#t:ring/0"},{"type":"type","title":"Geometry.srid/0","doc":"The Spatial Reference System Identifier to identify projected, unprojected,\nand local spatial coordinate system definitions.","ref":"Geometry.html#t:srid/0"},{"type":"type","title":"Geometry.t/0","doc":"The supported geometries.","ref":"Geometry.html#t:t/0"},{"type":"function","title":"Geometry.to_ewkb/2","doc":"Returns the EWKB representation of a geometry.\n\nIf the `srid` of the geometry is 0, a WKB is returned.\n\nThe optional `:endian` argument indicates whether `:xdr` big endian or `:ndr` little\nendian is returned. The default is `:ndr`.","ref":"Geometry.html#to_ewkb/2"},{"type":"function","title":"Examples - Geometry.to_ewkb/2","doc":"iex> PointZ.new(1, 2, 3, 3825)\n    ...> |> Geometry.to_ewkb()\n    ...> |> Base.encode16()\n    \"01010000A0F10E0000000000000000F03F00000000000000400000000000000840\"\n\n    iex> PointZ.new(1, 2, 3, 0)\n    ...> |> Geometry.to_ewkb()\n    ...> |> Base.encode16()\n    \"0101000080000000000000F03F00000000000000400000000000000840\"\n\n    iex> Point.new(1, 2, 3825)\n    ...> |> Geometry.to_ewkb(:xdr)\n    ...> |> Base.encode16()\n    \"002000000100000EF13FF00000000000004000000000000000\"","ref":"Geometry.html#to_ewkb/2-examples"},{"type":"function","title":"Geometry.to_ewkt/1","doc":"Returns the EWKT representation of the given `geometry`.\n\nIf the `srid` of the geometry is `0`, a WKT is returned.","ref":"Geometry.html#to_ewkt/1"},{"type":"function","title":"Examples - Geometry.to_ewkt/1","doc":"iex> Geometry.to_ewkt(PointZ.new(1.1, 2.2, 3.3, 4211))\n    \"SRID=4211;Point Z (1.1 2.2 3.3)\"\n\n    iex> Geometry.to_ewkt(LineString.new([Point.new(1, 2), Point.new(3, 4)], 3825))\n    \"SRID=3825;LineString (1 2, 3 4)\"\n\n    iex> Geometry.to_ewkt(Point.new(1, 2))\n    \"Point (1 2)\"","ref":"Geometry.html#to_ewkt/1-examples"},{"type":"function","title":"Geometry.to_geo_json/1","doc":"Returns the GeoJSON term representation of a geometry.","ref":"Geometry.html#to_geo_json/1"},{"type":"function","title":"Examples - Geometry.to_geo_json/1","doc":"iex> Geometry.to_geo_json(PointZ.new(1.2, 3.4, 5.6))\n    %{\"type\" => \"Point\", \"coordinates\" => [1.2, 3.4, 5.6]}\n\n    iex> Geometry.to_geo_json(LineString.new([Point.new(1, 2), Point.new(3, 4)]))\n    %{\"type\" => \"LineString\", \"coordinates\" => [[1, 2], [3, 4]]}","ref":"Geometry.html#to_geo_json/1-examples"},{"type":"function","title":"Geometry.to_wkb/2","doc":"Returns the WKB representation of a geometry.\n\nThe optional `:endian` argument indicates whether `:xdr` big endian or `:ndr` little\nendian is returned. The default is `:ndr`.","ref":"Geometry.html#to_wkb/2"},{"type":"function","title":"Examples - Geometry.to_wkb/2","doc":"iex> PointZ.new(1, 2, 3)\n    ...> |> Geometry.to_wkb()\n    ...> |> Base.encode16()\n    \"0101000080000000000000F03F00000000000000400000000000000840\"\n\n    iex> PointZ.new(1, 2, 3)\n    ...> |> Geometry.to_wkb(:xdr)\n    ...> |> Base.encode16()\n    \"00800000013FF000000000000040000000000000004008000000000000\"","ref":"Geometry.html#to_wkb/2-examples"},{"type":"function","title":"Geometry.to_wkt/1","doc":"Returns the WKT representation of the given `geometry`.","ref":"Geometry.html#to_wkt/1"},{"type":"function","title":"Examples - Geometry.to_wkt/1","doc":"iex> Geometry.to_wkt(PointZ.new(1.1, 2.2, 3.3))\n    \"Point Z (1.1 2.2 3.3)\"\n\n    iex> Geometry.to_wkt(LineString.new([Point.new(1, 2), Point.new(3, 4)]))\n    \"LineString (1 2, 3 4)\"\n\n    iex> Geometry.to_wkt(Point.new(1, 2))\n    \"Point (1 2)\"","ref":"Geometry.html#to_wkt/1-examples"},{"type":"type","title":"Geometry.wkb/0","doc":"[Well-Known Binary](https://en.wikipedia.org/wiki/Well-known_text_representation_of_geometry#Well-known_binary)\n(WKB) is the binary representation of WKT.","ref":"Geometry.html#t:wkb/0"},{"type":"type","title":"Geometry.wkt/0","doc":"[Well-Known Text](https://en.wikipedia.org/wiki/Well-known_text_representation_of_geometry)\n(WKT) is a text markup language for representing vector geometry objects.","ref":"Geometry.html#t:wkt/0"},{"type":"module","title":"Geometry.LineString","doc":"A line-string struct, representing a 2D line.\n\nA non-empty line-string requires at least two points.","ref":"Geometry.LineString.html"},{"type":"function","title":"Geometry.LineString.new/0","doc":"Creates an empty `LineString`.","ref":"Geometry.LineString.html#new/0"},{"type":"function","title":"Examples - Geometry.LineString.new/0","doc":"iex> LineString.new()\n    %LineString{path: [], srid: 0}","ref":"Geometry.LineString.html#new/0-examples"},{"type":"function","title":"Geometry.LineString.new/2","doc":"Creates a `LineString` from the given `Geometry.Point`s.","ref":"Geometry.LineString.html#new/2"},{"type":"function","title":"Examples - Geometry.LineString.new/2","doc":"iex> LineString.new([Point.new(1, 2), Point.new(3, 4)])\n    %LineString{path: [[1, 2], [3, 4]], srid: 0}","ref":"Geometry.LineString.html#new/2-examples"},{"type":"type","title":"Geometry.LineString.t/0","doc":"","ref":"Geometry.LineString.html#t:t/0"},{"type":"module","title":"Geometry.LineStringM","doc":"A line-string struct, representing a 2D line with a measurement.\n\nA non-empty line-string requires at least two path.","ref":"Geometry.LineStringM.html"},{"type":"function","title":"Geometry.LineStringM.new/0","doc":"Creates an empty `LineStringM`.","ref":"Geometry.LineStringM.html#new/0"},{"type":"function","title":"Examples - Geometry.LineStringM.new/0","doc":"iex> LineStringM.new()\n    %LineStringM{path: [], srid: 0}","ref":"Geometry.LineStringM.html#new/0-examples"},{"type":"function","title":"Geometry.LineStringM.new/2","doc":"Creates a `LineStringM` from the given `Geometry.PointM`s.","ref":"Geometry.LineStringM.html#new/2"},{"type":"function","title":"Examples - Geometry.LineStringM.new/2","doc":"iex> LineStringM.new([PointM.new(1, 2, 4), PointM.new(3, 4, 6)])\n    %LineStringM{path: [[1, 2, 4], [3, 4, 6]], srid: 0}","ref":"Geometry.LineStringM.html#new/2-examples"},{"type":"type","title":"Geometry.LineStringM.t/0","doc":"","ref":"Geometry.LineStringM.html#t:t/0"},{"type":"module","title":"Geometry.Point","doc":"A point struct, representing a 2D point.","ref":"Geometry.Point.html"},{"type":"function","title":"Geometry.Point.new/0","doc":"Creates an empty `Point`.","ref":"Geometry.Point.html#new/0"},{"type":"function","title":"Examples - Geometry.Point.new/0","doc":"iex> Point.new()\n    %Point{coordinates: []}","ref":"Geometry.Point.html#new/0-examples"},{"type":"function","title":"Geometry.Point.new/1","doc":"Creates a `Point` from the given `coordinate`.","ref":"Geometry.Point.html#new/1"},{"type":"function","title":"Examples - Geometry.Point.new/1","doc":"iex> Point.new([1.5, -2.1])\n    %Point{coordinates: [1.5, -2.1], srid: 0}","ref":"Geometry.Point.html#new/1-examples"},{"type":"function","title":"Geometry.Point.new/2","doc":"Creates a `Point` from the given `x` and `y`, or a coordinate and an srid","ref":"Geometry.Point.html#new/2"},{"type":"function","title":"Examples - Geometry.Point.new/2","doc":"iex> Point.new(-1.1, 2.2)\n    %Point{coordinates: [-1.1, 2.2], srid: 0}","ref":"Geometry.Point.html#new/2-examples"},{"type":"function","title":"Geometry.Point.new/3","doc":"Creates a `Point` from the given `x` and `y`.","ref":"Geometry.Point.html#new/3"},{"type":"function","title":"Examples - Geometry.Point.new/3","doc":"iex> Point.new(-1.1, 2.2, 4326)\n    %Point{coordinates: [-1.1, 2.2], srid: 4326}","ref":"Geometry.Point.html#new/3-examples"},{"type":"type","title":"Geometry.Point.t/0","doc":"","ref":"Geometry.Point.html#t:t/0"},{"type":"module","title":"Geometry.PointM","doc":"A point struct, representing a 2D point with a measurement.","ref":"Geometry.PointM.html"},{"type":"function","title":"Geometry.PointM.new/0","doc":"Creates an empty `PointM`.","ref":"Geometry.PointM.html#new/0"},{"type":"function","title":"Examples - Geometry.PointM.new/0","doc":"iex> PointM.new()\n    %PointM{coordinates: []}","ref":"Geometry.PointM.html#new/0-examples"},{"type":"function","title":"Geometry.PointM.new/2","doc":"Creates a `PointM` from the given `coordinate`.","ref":"Geometry.PointM.html#new/2"},{"type":"function","title":"Examples - Geometry.PointM.new/2","doc":"iex> PointM.new([1.5, -2.1, 4])\n    %PointM{coordinates: [1.5, -2.1, 4]}","ref":"Geometry.PointM.html#new/2-examples"},{"type":"function","title":"Geometry.PointM.new/4","doc":"Creates a `PointM` from the given `x`, `y`, and `m`.","ref":"Geometry.PointM.html#new/4"},{"type":"function","title":"Examples - Geometry.PointM.new/4","doc":"iex> PointM.new(-1.1, 2.2, 4)\n    %PointM{coordinates: [-1.1, 2.2, 4], srid: 0}","ref":"Geometry.PointM.html#new/4-examples"},{"type":"type","title":"Geometry.PointM.t/0","doc":"","ref":"Geometry.PointM.html#t:t/0"},{"type":"module","title":"Geometry.Polygon","doc":"A polygon struct, representing a 2D polygon.\n\nA non-empty line-string requires at least one ring with four coordinates.","ref":"Geometry.Polygon.html"},{"type":"function","title":"Geometry.Polygon.new/0","doc":"Creates an empty `Polygon`.","ref":"Geometry.Polygon.html#new/0"},{"type":"function","title":"Examples - Geometry.Polygon.new/0","doc":"iex> Polygon.new()\n    %Polygon{rings: []}","ref":"Geometry.Polygon.html#new/0-examples"},{"type":"function","title":"Geometry.Polygon.new/2","doc":"Creates a `Polygon` from the given `rings`.","ref":"Geometry.Polygon.html#new/2"},{"type":"function","title":"Examples - Geometry.Polygon.new/2","doc":"iex> Polygon.new([\n    ...>   LineString.new([\n    ...>     Point.new(35, 10),\n    ...>     Point.new(45, 45),\n    ...>     Point.new(10, 20),\n    ...>     Point.new(35, 10)\n    ...>   ]),\n    ...>   LineString.new([\n    ...>     Point.new(20, 30),\n    ...>     Point.new(35, 35),\n    ...>     Point.new(30, 20),\n    ...>     Point.new(20, 30)\n    ...>   ])\n    ...> ])\n    %Polygon{\n      rings: [\n        [[35, 10], [45, 45], [10, 20], [35, 10]],\n        [[20, 30], [35, 35], [30, 20], [20, 30]]\n      ],\n      srid: 0\n    }\n\n    iex> Polygon.new()\n    %Polygon{}","ref":"Geometry.Polygon.html#new/2-examples"},{"type":"type","title":"Geometry.Polygon.t/0","doc":"","ref":"Geometry.Polygon.html#t:t/0"},{"type":"module","title":"Geometry.PolygonM","doc":"A polygon struct, representing a 2D polygon with a measurement.\n\nA non-empty line-string requires at least one ring with four coordinates.","ref":"Geometry.PolygonM.html"},{"type":"function","title":"Geometry.PolygonM.new/0","doc":"Creates an empty `PolygonM`.","ref":"Geometry.PolygonM.html#new/0"},{"type":"function","title":"Examples - Geometry.PolygonM.new/0","doc":"iex> PolygonM.new()\n    %PolygonM{rings: []}","ref":"Geometry.PolygonM.html#new/0-examples"},{"type":"function","title":"Geometry.PolygonM.new/2","doc":"Creates a `PolygonM` from the given `rings`.","ref":"Geometry.PolygonM.html#new/2"},{"type":"function","title":"Examples - Geometry.PolygonM.new/2","doc":"iex> PolygonM.new([\n    ...>   LineStringM.new([\n    ...>     PointM.new(35, 10, 14),\n    ...>     PointM.new(45, 45, 24),\n    ...>     PointM.new(10, 20, 34),\n    ...>     PointM.new(35, 10, 14)\n    ...>   ]),\n    ...>   LineStringM.new([\n    ...>     PointM.new(20, 30, 14),\n    ...>     PointM.new(35, 35, 24),\n    ...>     PointM.new(30, 20, 34),\n    ...>     PointM.new(20, 30, 14)\n    ...>   ])\n    ...> ])\n    %PolygonM{\n      rings: [\n        [[35, 10, 14], [45, 45, 24], [10, 20, 34], [35, 10, 14]],\n        [[20, 30, 14], [35, 35, 24], [30, 20, 34], [20, 30, 14]]\n      ],\n      srid: 0\n    }\n\n    iex> PolygonM.new()\n    %PolygonM{}","ref":"Geometry.PolygonM.html#new/2-examples"},{"type":"type","title":"Geometry.PolygonM.t/0","doc":"","ref":"Geometry.PolygonM.html#t:t/0"},{"type":"module","title":"Geometry.LineStringZ","doc":"A line-string struct, representing a 3D line.\n\nA non-empty line-string requires at least two coordinates.","ref":"Geometry.LineStringZ.html"},{"type":"function","title":"Geometry.LineStringZ.new/0","doc":"Creates an empty `LineStringZ`.","ref":"Geometry.LineStringZ.html#new/0"},{"type":"function","title":"Examples - Geometry.LineStringZ.new/0","doc":"iex> LineStringZ.new()\n    %LineStringZ{path: [], srid: 0}","ref":"Geometry.LineStringZ.html#new/0-examples"},{"type":"function","title":"Geometry.LineStringZ.new/2","doc":"Creates a `LineStringZ` from the given `Geometry.PointZ`s.","ref":"Geometry.LineStringZ.html#new/2"},{"type":"function","title":"Examples - Geometry.LineStringZ.new/2","doc":"iex> LineStringZ.new([PointZ.new(1, 2, 3), PointZ.new(3, 4, 5)])\n    %LineStringZ{path: [[1, 2, 3], [3, 4, 5]], srid: 0}","ref":"Geometry.LineStringZ.html#new/2-examples"},{"type":"type","title":"Geometry.LineStringZ.t/0","doc":"","ref":"Geometry.LineStringZ.html#t:t/0"},{"type":"module","title":"Geometry.LineStringZM","doc":"A line-string struct, representing a 3D line with a measurement.\n\nA non-empty line-string requires at least two coordinates.","ref":"Geometry.LineStringZM.html"},{"type":"function","title":"Geometry.LineStringZM.new/0","doc":"Creates an empty `LineStringZM`.","ref":"Geometry.LineStringZM.html#new/0"},{"type":"function","title":"Examples - Geometry.LineStringZM.new/0","doc":"iex> LineStringZM.new()\n    %LineStringZM{path: [], srid: 0}","ref":"Geometry.LineStringZM.html#new/0-examples"},{"type":"function","title":"Geometry.LineStringZM.new/2","doc":"Creates a `LineStringZM` from the given `Geometry.PointZM`s.","ref":"Geometry.LineStringZM.html#new/2"},{"type":"function","title":"Examples - Geometry.LineStringZM.new/2","doc":"iex> LineStringZM.new([PointZM.new(1, 2, 3, 4), PointZM.new(3, 4, 5, 6)])\n    %LineStringZM{path: [[1, 2, 3, 4], [3, 4, 5, 6]], srid: 0}","ref":"Geometry.LineStringZM.html#new/2-examples"},{"type":"type","title":"Geometry.LineStringZM.t/0","doc":"","ref":"Geometry.LineStringZM.html#t:t/0"},{"type":"module","title":"Geometry.PointZ","doc":"A point struct, representing a 3D point.","ref":"Geometry.PointZ.html"},{"type":"function","title":"Geometry.PointZ.new/0","doc":"Creates an empty `PointZ`.","ref":"Geometry.PointZ.html#new/0"},{"type":"function","title":"Examples - Geometry.PointZ.new/0","doc":"iex> PointZ.new()\n    %PointZ{coordinates: []}","ref":"Geometry.PointZ.html#new/0-examples"},{"type":"function","title":"Geometry.PointZ.new/2","doc":"Creates a `PointZ` from the given `coordinate`.","ref":"Geometry.PointZ.html#new/2"},{"type":"function","title":"Examples - Geometry.PointZ.new/2","doc":"iex> PointZ.new([1.5, -2.1, 3])\n    %PointZ{coordinates: [1.5, -2.1, 3]}","ref":"Geometry.PointZ.html#new/2-examples"},{"type":"function","title":"Geometry.PointZ.new/4","doc":"Creates a `PointZ` from the given `x`, `y`, and `z`.","ref":"Geometry.PointZ.html#new/4"},{"type":"function","title":"Examples - Geometry.PointZ.new/4","doc":"iex> PointZ.new(-1.1, 2.2, 3)\n    %PointZ{coordinates: [-1.1, 2.2, 3], srid: 0}","ref":"Geometry.PointZ.html#new/4-examples"},{"type":"type","title":"Geometry.PointZ.t/0","doc":"","ref":"Geometry.PointZ.html#t:t/0"},{"type":"module","title":"Geometry.PointZM","doc":"A point struct, representing a 3D point with a measurement.","ref":"Geometry.PointZM.html"},{"type":"function","title":"Geometry.PointZM.new/0","doc":"Creates an empty `PointZM`.","ref":"Geometry.PointZM.html#new/0"},{"type":"function","title":"Examples - Geometry.PointZM.new/0","doc":"iex> PointZM.new()\n    %PointZM{coordinates: []}","ref":"Geometry.PointZM.html#new/0-examples"},{"type":"function","title":"Geometry.PointZM.new/2","doc":"Creates a `PointZM` from the given `coordinate`.","ref":"Geometry.PointZM.html#new/2"},{"type":"function","title":"Examples - Geometry.PointZM.new/2","doc":"iex> PointZM.new([1.5, -2.1, 3, 4])\n    %PointZM{coordinates: [1.5, -2.1, 3, 4]}","ref":"Geometry.PointZM.html#new/2-examples"},{"type":"function","title":"Geometry.PointZM.new/5","doc":"Creates a `PointZM` from the given `x`, `y`, `z`, and `m`.","ref":"Geometry.PointZM.html#new/5"},{"type":"function","title":"Examples - Geometry.PointZM.new/5","doc":"iex> PointZM.new(-1.1, 2.2, 3, 4)\n    %PointZM{coordinates: [-1.1, 2.2, 3, 4], srid: 0}","ref":"Geometry.PointZM.html#new/5-examples"},{"type":"type","title":"Geometry.PointZM.t/0","doc":"","ref":"Geometry.PointZM.html#t:t/0"},{"type":"module","title":"Geometry.PolygonZ","doc":"A polygon struct, representing a 3D polygon.\n\nA non-empty line-string requires at least one ring with four coordinates.","ref":"Geometry.PolygonZ.html"},{"type":"function","title":"Geometry.PolygonZ.new/0","doc":"Creates an empty `PolygonZ`.","ref":"Geometry.PolygonZ.html#new/0"},{"type":"function","title":"Examples - Geometry.PolygonZ.new/0","doc":"iex> PolygonZ.new()\n    %PolygonZ{rings: []}","ref":"Geometry.PolygonZ.html#new/0-examples"},{"type":"function","title":"Geometry.PolygonZ.new/2","doc":"Creates a `PolygonZ` from the given `rings`.","ref":"Geometry.PolygonZ.html#new/2"},{"type":"function","title":"Examples - Geometry.PolygonZ.new/2","doc":"iex> PolygonZ.new([\n    ...>   LineStringZ.new([\n    ...>     PointZ.new(35, 10, 13),\n    ...>     PointZ.new(45, 45, 23),\n    ...>     PointZ.new(10, 20, 33),\n    ...>     PointZ.new(35, 10, 13)\n    ...>   ]),\n    ...>   LineStringZ.new([\n    ...>     PointZ.new(20, 30, 13),\n    ...>     PointZ.new(35, 35, 23),\n    ...>     PointZ.new(30, 20, 33),\n    ...>     PointZ.new(20, 30, 13)\n    ...>   ])\n    ...> ])\n    %PolygonZ{\n      rings: [\n        [[35, 10, 13], [45, 45, 23], [10, 20, 33], [35, 10, 13]],\n        [[20, 30, 13], [35, 35, 23], [30, 20, 33], [20, 30, 13]]\n      ],\n      srid: 0\n    }\n\n    iex> PolygonZ.new()\n    %PolygonZ{}","ref":"Geometry.PolygonZ.html#new/2-examples"},{"type":"type","title":"Geometry.PolygonZ.t/0","doc":"","ref":"Geometry.PolygonZ.html#t:t/0"},{"type":"module","title":"Geometry.PolygonZM","doc":"A polygon struct, representing a 3D polygon with a measurement.\n\nA non-empty line-string requires at least one ring with four coordinates.","ref":"Geometry.PolygonZM.html"},{"type":"function","title":"Geometry.PolygonZM.new/0","doc":"Creates an empty `PolygonZM`.","ref":"Geometry.PolygonZM.html#new/0"},{"type":"function","title":"Examples - Geometry.PolygonZM.new/0","doc":"iex> PolygonZM.new()\n    %PolygonZM{rings: []}","ref":"Geometry.PolygonZM.html#new/0-examples"},{"type":"function","title":"Geometry.PolygonZM.new/2","doc":"Creates a `PolygonZM` from the given `rings`.","ref":"Geometry.PolygonZM.html#new/2"},{"type":"function","title":"Examples - Geometry.PolygonZM.new/2","doc":"iex> PolygonZM.new([\n    ...>   LineStringZM.new([\n    ...>     PointZM.new(35, 10, 13, 14),\n    ...>     PointZM.new(45, 45, 23, 24),\n    ...>     PointZM.new(10, 20, 33, 34),\n    ...>     PointZM.new(35, 10, 13, 14)\n    ...>   ]),\n    ...>   LineStringZM.new([\n    ...>     PointZM.new(20, 30, 13, 14),\n    ...>     PointZM.new(35, 35, 23, 24),\n    ...>     PointZM.new(30, 20, 33, 34),\n    ...>     PointZM.new(20, 30, 13, 14)\n    ...>   ])\n    ...> ])\n    %PolygonZM{\n      rings: [\n        [[35, 10, 13, 14], [45, 45, 23, 24], [10, 20, 33, 34], [35, 10, 13, 14]],\n        [[20, 30, 13, 14], [35, 35, 23, 24], [30, 20, 33, 34], [20, 30, 13, 14]]\n      ],\n      srid: 0\n    }\n\n    iex> PolygonZM.new()\n    %PolygonZM{}","ref":"Geometry.PolygonZM.html#new/2-examples"},{"type":"type","title":"Geometry.PolygonZM.t/0","doc":"","ref":"Geometry.PolygonZM.html#t:t/0"},{"type":"module","title":"Geometry.MultiLineString","doc":"A set of line-strings from type `Geometry.LineString`\n\n`MultiLineStringMZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiLineString.html"},{"type":"module","title":"Examples - Geometry.MultiLineString","doc":"iex> Enum.map(\n    ...>   MultiLineString.new([\n    ...>     LineString.new([\n    ...>       Point.new(1, 2),\n    ...>       Point.new(3, 4)\n    ...>     ]),\n    ...>     LineString.new([\n    ...>       Point.new(1, 2),\n    ...>       Point.new(11, 12),\n    ...>       Point.new(13, 14)\n    ...>     ])\n    ...>   ]),\n    ...>   fn line_string -> length line_string end\n    ...> )\n    [2, 3]\n\n    iex> Enum.into(\n    ...>   [LineString.new([Point.new(1, 2), Point.new(5, 6)])],\n    ...>   MultiLineString.new())\n    %MultiLineString{\n      line_strings: [[[1, 2], [5, 6]]], srid: 0\n    }","ref":"Geometry.MultiLineString.html#module-examples"},{"type":"function","title":"Geometry.MultiLineString.new/0","doc":"Creates an empty `MultiLineString`.","ref":"Geometry.MultiLineString.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiLineString.new/0","doc":"iex> MultiLineString.new()\n    %MultiLineString{}","ref":"Geometry.MultiLineString.html#new/0-examples"},{"type":"function","title":"Geometry.MultiLineString.new/2","doc":"Creates a `MultiLineString` from the given `Geometry.MultiLineString`s.","ref":"Geometry.MultiLineString.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiLineString.new/2","doc":"iex> MultiLineString.new([\n    ...>   LineString.new([\n    ...>     Point.new(1, 2),\n    ...>     Point.new(2, 3),\n    ...>     Point.new(3, 4)\n    ...>   ]),\n    ...>   LineString.new([\n    ...>     Point.new(10, 20),\n    ...>     Point.new(30, 40)\n    ...>   ])\n    ...> ])\n    %Geometry.MultiLineString{\n      line_strings: [\n          [[1, 2], [2, 3], [3, 4]],\n          [[10, 20], [30, 40]]\n        ],\n      srid: 0\n    }\n\n    iex> MultiLineString.new([])\n    %MultiLineString{line_strings: [], srid: 0}","ref":"Geometry.MultiLineString.html#new/2-examples"},{"type":"type","title":"Geometry.MultiLineString.t/0","doc":"","ref":"Geometry.MultiLineString.html#t:t/0"},{"type":"module","title":"Geometry.MultiLineStringM","doc":"A set of line-strings from type `Geometry.LineStringM`\n\n`MultiLineStringMZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiLineStringM.html"},{"type":"module","title":"Examples - Geometry.MultiLineStringM","doc":"iex> Enum.map(\n    ...>   MultiLineStringM.new([\n    ...>     LineStringM.new([\n    ...>       PointM.new(1, 2, 4),\n    ...>       PointM.new(3, 4, 6)\n    ...>     ]),\n    ...>     LineStringM.new([\n    ...>       PointM.new(1, 2, 4),\n    ...>       PointM.new(11, 12, 14),\n    ...>       PointM.new(13, 14, 16)\n    ...>     ])\n    ...>   ]),\n    ...>   fn line_string -> length line_string end\n    ...> )\n    [2, 3]\n\n    iex> Enum.into(\n    ...>   [LineStringM.new([PointM.new(1, 2, 4), PointM.new(5, 6, 8)])],\n    ...>   MultiLineStringM.new())\n    %MultiLineStringM{line_strings: [[[1, 2, 4], [5, 6, 8]]], srid: 0}","ref":"Geometry.MultiLineStringM.html#module-examples"},{"type":"function","title":"Geometry.MultiLineStringM.new/0","doc":"Creates an empty `MultiLineStringM`.","ref":"Geometry.MultiLineStringM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiLineStringM.new/0","doc":"iex> MultiLineStringM.new()\n    %MultiLineStringM{}","ref":"Geometry.MultiLineStringM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiLineStringM.new/2","doc":"Creates a `MultiLineStringM` from the given `Geometry.MultiLineStringM`s.","ref":"Geometry.MultiLineStringM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiLineStringM.new/2","doc":"iex> MultiLineStringM.new([\n    ...>   LineStringM.new([\n    ...>     PointM.new(1, 2, 4),\n    ...>     PointM.new(2, 3, 5),\n    ...>     PointM.new(3, 4, 6)\n    ...>   ]),\n    ...>   LineStringM.new([\n    ...>     PointM.new(10, 20, 40),\n    ...>     PointM.new(30, 40, 60)\n    ...>   ])\n    ...> ])\n    %Geometry.MultiLineStringM{\n      line_strings:\n        [\n          [[1, 2, 4], [2, 3, 5], [3, 4, 6]],\n          [[10, 20, 40], [30, 40, 60]]\n        ],\n        srid: 0\n    }\n\n    iex> MultiLineStringM.new([])\n    %MultiLineStringM{}","ref":"Geometry.MultiLineStringM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiLineStringM.t/0","doc":"","ref":"Geometry.MultiLineStringM.html#t:t/0"},{"type":"module","title":"Geometry.MultiPoint","doc":"A set of points from type `Geometry.Point`.\n\n`MultiPoint` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPoint.html"},{"type":"module","title":"Examples - Geometry.MultiPoint","doc":"iex> Enum.map(\n    ...>   MultiPoint.new([\n    ...>     Point.new(1, 2),\n    ...>     Point.new(3, 4)\n    ...>   ]),\n    ...>   fn [x, _y] -> x end\n    ...> )\n    [1, 3]\n\n    iex> Enum.into([Point.new(1, 2)], MultiPoint.new())\n    %MultiPoint{points: [[1, 2]]}","ref":"Geometry.MultiPoint.html#module-examples"},{"type":"function","title":"Geometry.MultiPoint.new/0","doc":"Creates an empty `MultiPoint`.","ref":"Geometry.MultiPoint.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPoint.new/0","doc":"iex> MultiPoint.new()\n    %MultiPoint{points: [], srid: 0}","ref":"Geometry.MultiPoint.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPoint.new/2","doc":"Creates a `MultiPoint` from the given `Geometry.Point`s.","ref":"Geometry.MultiPoint.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPoint.new/2","doc":"iex> MultiPoint.new([\n    ...>   Point.new(1, 2),\n    ...>   Point.new(3, 4)\n    ...> ])\n    %MultiPoint{points: [[1, 2], [3, 4]], srid: 0}\n\n    iex> MultiPoint.new([])\n    %MultiPoint{points: [], srid: 0}","ref":"Geometry.MultiPoint.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPoint.t/0","doc":"","ref":"Geometry.MultiPoint.html#t:t/0"},{"type":"module","title":"Geometry.MultiPointM","doc":"A set of points from type `Geometry.PointM`.\n\n`MultiPointM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPointM.html"},{"type":"module","title":"Examples - Geometry.MultiPointM","doc":"iex> Enum.map(\n    ...>   MultiPointM.new([\n    ...>     PointM.new(1, 2, 4),\n    ...>     PointM.new(3, 4, 6)\n    ...>   ]),\n    ...>   fn [x, _y, _m] -> x end\n    ...> )\n    [1, 3]\n\n    iex> Enum.into([PointM.new(1, 2, 4)], MultiPointM.new())\n    %MultiPointM{points: [[1, 2, 4]]}","ref":"Geometry.MultiPointM.html#module-examples"},{"type":"function","title":"Geometry.MultiPointM.new/0","doc":"Creates an empty `MultiPointM`.","ref":"Geometry.MultiPointM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPointM.new/0","doc":"iex> MultiPointM.new()\n    %MultiPointM{points: [], srid: 0}","ref":"Geometry.MultiPointM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPointM.new/2","doc":"Creates a `MultiPointM` from the given `Geometry.PointM`s.","ref":"Geometry.MultiPointM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPointM.new/2","doc":"iex> MultiPointM.new([\n    ...>   PointM.new(1, 2, 4),\n    ...>   PointM.new(3, 4, 6)\n    ...> ])\n    %MultiPointM{points: [[1, 2, 4], [3, 4, 6]], srid: 0}\n\n    iex> MultiPointM.new([])\n    %MultiPointM{points: [], srid: 0}","ref":"Geometry.MultiPointM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPointM.t/0","doc":"","ref":"Geometry.MultiPointM.html#t:t/0"},{"type":"module","title":"Geometry.MultiPolygon","doc":"A set of polygons from type `Geometry.Polygon`\n\n`MultiPoint` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPolygon.html"},{"type":"module","title":"Examples - Geometry.MultiPolygon","doc":"iex> Enum.map(\n    ...>   MultiPolygon.new([\n    ...>     Polygon.new([\n    ...>       LineString.new([\n    ...>         Point.new(11, 12),\n    ...>         Point.new(11, 22),\n    ...>         Point.new(31, 22),\n    ...>         Point.new(11, 12)\n    ...>       ]),\n    ...>     ]),\n    ...>     Polygon.new([\n    ...>       LineString.new([\n    ...>         Point.new(35, 10),\n    ...>         Point.new(45, 45),\n    ...>         Point.new(10, 20),\n    ...>         Point.new(35, 10)\n    ...>       ]),\n    ...>       LineString.new([\n    ...>         Point.new(20, 30),\n    ...>         Point.new(35, 35),\n    ...>         Point.new(30, 20),\n    ...>         Point.new(20, 30)\n    ...>       ])\n    ...>     ])\n    ...>   ]),\n    ...>   fn polygon -> length(polygon) == 1 end\n    ...> )\n    [true, false]\n\n    iex> Enum.into(\n    ...>   [\n    ...>     Polygon.new([\n    ...>       LineString.new([\n    ...>         Point.new(11, 12),\n    ...>         Point.new(11, 22),\n    ...>         Point.new(31, 22),\n    ...>         Point.new(11, 12)\n    ...>       ])\n    ...>     ])\n    ...>   ],\n    ...>   MultiPolygon.new())\n    %MultiPolygon{\n      polygons: [\n          [\n            [\n              [11, 12],\n              [11, 22],\n              [31, 22],\n              [11, 12]\n            ]\n          ]\n        ],\n      srid: 0\n    }","ref":"Geometry.MultiPolygon.html#module-examples"},{"type":"function","title":"Geometry.MultiPolygon.new/0","doc":"Creates an empty `MultiPolygon`.","ref":"Geometry.MultiPolygon.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPolygon.new/0","doc":"iex> MultiPolygon.new()\n    %MultiPolygon{polygons: []}","ref":"Geometry.MultiPolygon.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPolygon.new/2","doc":"Creates a `MultiPolygon` from the given `Geometry.MultiPolygon`s.","ref":"Geometry.MultiPolygon.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPolygon.new/2","doc":"iex> MultiPolygon.new([\n    ...>   Polygon.new([\n    ...>     LineString.new([\n    ...>       Point.new(6, 2),\n    ...>       Point.new(8, 2),\n    ...>       Point.new(8, 4),\n    ...>       Point.new(6, 2)\n    ...>     ]),\n    ...>   ]),\n    ...>   Polygon.new([\n    ...>     LineString.new([\n    ...>       Point.new(1, 1),\n    ...>       Point.new(9, 1),\n    ...>       Point.new(9, 8),\n    ...>       Point.new(1, 1)\n    ...>     ]),\n    ...>     LineString.new([\n    ...>       Point.new(6, 2),\n    ...>       Point.new(7, 2),\n    ...>       Point.new(7, 3),\n    ...>       Point.new(6, 2)\n    ...>     ])\n    ...>   ])\n    ...> ])\n    %MultiPolygon{\n      polygons: [\n          [[[6, 2], [8, 2], [8, 4], [6, 2]]],\n          [\n            [[1, 1], [9, 1], [9, 8], [1, 1]],\n            [[6, 2], [7, 2], [7, 3], [6, 2]]\n          ]\n        ],\n        srid: 0\n    }\n\n    iex> MultiPolygon.new([])\n    %MultiPolygon{}","ref":"Geometry.MultiPolygon.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPolygon.t/0","doc":"","ref":"Geometry.MultiPolygon.html#t:t/0"},{"type":"module","title":"Geometry.MultiPolygonM","doc":"A set of polygons from type `Geometry.PolygonM`\n\n`MultiPointM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPolygonM.html"},{"type":"module","title":"Examples - Geometry.MultiPolygonM","doc":"iex> Enum.map(\n    ...>   MultiPolygonM.new([\n    ...>     PolygonM.new([\n    ...>       LineStringM.new([\n    ...>         PointM.new(11, 12, 14),\n    ...>         PointM.new(11, 22, 24),\n    ...>         PointM.new(31, 22, 34),\n    ...>         PointM.new(11, 12, 14)\n    ...>       ]),\n    ...>     ]),\n    ...>     PolygonM.new([\n    ...>       LineStringM.new([\n    ...>         PointM.new(35, 10, 14),\n    ...>         PointM.new(45, 45, 24),\n    ...>         PointM.new(10, 20, 34),\n    ...>         PointM.new(35, 10, 14)\n    ...>       ]),\n    ...>       LineStringM.new([\n    ...>         PointM.new(20, 30, 14),\n    ...>         PointM.new(35, 35, 24),\n    ...>         PointM.new(30, 20, 34),\n    ...>         PointM.new(20, 30, 14)\n    ...>       ])\n    ...>     ])\n    ...>   ]),\n    ...>   fn polygon -> length(polygon) == 1 end\n    ...> )\n    [true, false]\n\n    iex> Enum.into(\n    ...>   [\n    ...>     PolygonM.new([\n    ...>       LineStringM.new([\n    ...>         PointM.new(11, 12, 14),\n    ...>         PointM.new(11, 22, 24),\n    ...>         PointM.new(31, 22, 34),\n    ...>         PointM.new(11, 12, 14)\n    ...>       ])\n    ...>     ])\n    ...>   ],\n    ...>   MultiPolygonM.new())\n    %MultiPolygonM{\n      polygons: [\n          [\n            [\n              [11, 12, 14],\n              [11, 22, 24],\n              [31, 22, 34],\n              [11, 12, 14]\n            ]\n          ]\n        ],\n        srid: 0\n    }","ref":"Geometry.MultiPolygonM.html#module-examples"},{"type":"function","title":"Geometry.MultiPolygonM.new/0","doc":"Creates an empty `MultiPolygonM`.","ref":"Geometry.MultiPolygonM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPolygonM.new/0","doc":"iex> MultiPolygonM.new()\n    %MultiPolygonM{}","ref":"Geometry.MultiPolygonM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPolygonM.new/2","doc":"Creates a `MultiPolygonM` from the given `Geometry.MultiPolygonM`s.","ref":"Geometry.MultiPolygonM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPolygonM.new/2","doc":"iex> MultiPolygonM.new([\n    ...>   PolygonM.new([\n    ...>     LineStringM.new([\n    ...>       PointM.new(6, 2, 4),\n    ...>       PointM.new(8, 2, 5),\n    ...>       PointM.new(8, 4, 6),\n    ...>       PointM.new(6, 2, 4)\n    ...>     ]),\n    ...>   ]),\n    ...>   PolygonM.new([\n    ...>     LineStringM.new([\n    ...>       PointM.new(1, 1, 4),\n    ...>       PointM.new(9, 1, 5),\n    ...>       PointM.new(9, 8, 6),\n    ...>       PointM.new(1, 1, 4)\n    ...>     ]),\n    ...>     LineStringM.new([\n    ...>       PointM.new(6, 2, 4),\n    ...>       PointM.new(7, 2, 5),\n    ...>       PointM.new(7, 3, 6),\n    ...>       PointM.new(6, 2, 4)\n    ...>     ])\n    ...>   ])\n    ...> ])\n    %MultiPolygonM{\n      polygons: [\n          [[[6, 2, 4], [8, 2, 5], [8, 4, 6], [6, 2, 4]]],\n          [\n            [[1, 1, 4], [9, 1, 5], [9, 8, 6], [1, 1, 4]],\n            [[6, 2, 4], [7, 2, 5], [7, 3, 6], [6, 2, 4]]\n          ]\n        ]\n    }\n\n    iex> MultiPolygonM.new([])\n    %MultiPolygonM{}","ref":"Geometry.MultiPolygonM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPolygonM.t/0","doc":"","ref":"Geometry.MultiPolygonM.html#t:t/0"},{"type":"module","title":"Geometry.MultiLineStringZ","doc":"A set of line-strings from type `Geometry.LineStringZ`\n\n`MultiLineStringZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiLineStringZ.html"},{"type":"module","title":"Examples - Geometry.MultiLineStringZ","doc":"iex> Enum.map(\n    ...>   MultiLineStringZ.new([\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(1, 2, 3),\n    ...>       PointZ.new(3, 4, 5)\n    ...>     ]),\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(1, 2, 3),\n    ...>       PointZ.new(11, 12, 13),\n    ...>       PointZ.new(13, 14, 15)\n    ...>     ])\n    ...>   ]),\n    ...>   fn line_string -> length line_string end\n    ...> )\n    [2, 3]\n\n    iex> Enum.into(\n    ...>   [LineStringZ.new([PointZ.new(1, 2, 3), PointZ.new(5, 6, 7)])],\n    ...>   MultiLineStringZ.new())\n    %MultiLineStringZ{line_strings: [[[1, 2, 3], [5, 6, 7]]], srid: 0}","ref":"Geometry.MultiLineStringZ.html#module-examples"},{"type":"function","title":"Geometry.MultiLineStringZ.new/0","doc":"Creates an empty `MultiLineStringZ`.","ref":"Geometry.MultiLineStringZ.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiLineStringZ.new/0","doc":"iex> MultiLineStringZ.new()\n    %MultiLineStringZ{}","ref":"Geometry.MultiLineStringZ.html#new/0-examples"},{"type":"function","title":"Geometry.MultiLineStringZ.new/2","doc":"Creates a `MultiLineStringZ` from the given `Geometry.MultiLineStringZ`s.","ref":"Geometry.MultiLineStringZ.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiLineStringZ.new/2","doc":"iex> MultiLineStringZ.new([\n    ...>   LineStringZ.new([\n    ...>     PointZ.new(1, 2, 3),\n    ...>     PointZ.new(2, 3, 4),\n    ...>     PointZ.new(3, 4, 5)\n    ...>   ]),\n    ...>   LineStringZ.new([\n    ...>     PointZ.new(10, 20, 30),\n    ...>     PointZ.new(30, 40, 50)\n    ...>   ])\n    ...> ])\n    %Geometry.MultiLineStringZ{\n      line_strings: [\n          [[1, 2, 3], [2, 3, 4], [3, 4, 5]],\n          [[10, 20, 30], [30, 40, 50]]\n        ],\n      srid: 0\n    }\n\n    iex> MultiLineStringZ.new([])\n    %MultiLineStringZ{}","ref":"Geometry.MultiLineStringZ.html#new/2-examples"},{"type":"type","title":"Geometry.MultiLineStringZ.t/0","doc":"","ref":"Geometry.MultiLineStringZ.html#t:t/0"},{"type":"module","title":"Geometry.MultiLineStringZM","doc":"A set of line-strings from type `Geometry.LineStringZM`\n\n`MultiLineStringZM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiLineStringZM.html"},{"type":"module","title":"Examples - Geometry.MultiLineStringZM","doc":"iex> Enum.map(\n    ...>   MultiLineStringZM.new([\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(1, 2, 3, 4),\n    ...>       PointZM.new(3, 4, 5, 6)\n    ...>     ]),\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(1, 2, 3, 4),\n    ...>       PointZM.new(11, 12, 13, 14),\n    ...>       PointZM.new(13, 14, 15, 16)\n    ...>     ])\n    ...>   ]),\n    ...>   fn line_string -> length line_string end\n    ...> )\n    [2, 3]\n\n    iex> Enum.into(\n    ...>   [LineStringZM.new([PointZM.new(1, 2, 3, 4), PointZM.new(5, 6, 7, 8)])],\n    ...>   MultiLineStringZM.new())\n    %MultiLineStringZM{line_strings: [[[1, 2, 3, 4], [5, 6, 7, 8]]]}","ref":"Geometry.MultiLineStringZM.html#module-examples"},{"type":"function","title":"Geometry.MultiLineStringZM.new/0","doc":"Creates an empty `MultiLineStringZM`.","ref":"Geometry.MultiLineStringZM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiLineStringZM.new/0","doc":"iex> MultiLineStringZM.new()\n    %MultiLineStringZM{}","ref":"Geometry.MultiLineStringZM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiLineStringZM.new/2","doc":"Creates a `MultiLineStringZM` from the given `Geometry.MultiLineStringZM`s.","ref":"Geometry.MultiLineStringZM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiLineStringZM.new/2","doc":"iex> MultiLineStringZM.new([\n    ...>   LineStringZM.new([\n    ...>     PointZM.new(1, 2, 3, 4),\n    ...>     PointZM.new(2, 3, 4, 5),\n    ...>     PointZM.new(3, 4, 5, 6)\n    ...>   ]),\n    ...>   LineStringZM.new([\n    ...>     PointZM.new(10, 20, 30, 40),\n    ...>     PointZM.new(30, 40, 50, 60)\n    ...>   ])\n    ...> ])\n    %Geometry.MultiLineStringZM{\n      line_strings: [\n          [[1, 2, 3, 4], [2, 3, 4, 5], [3, 4, 5, 6]],\n          [[10, 20, 30, 40], [30, 40, 50, 60]]\n        ],\n      srid: 0\n    }\n\n    iex> MultiLineStringZM.new([])\n    %MultiLineStringZM{}","ref":"Geometry.MultiLineStringZM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiLineStringZM.t/0","doc":"","ref":"Geometry.MultiLineStringZM.html#t:t/0"},{"type":"module","title":"Geometry.MultiPointZ","doc":"A set of coordinates from type `Geometry.PointZ`.\n\n`MultiPointZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPointZ.html"},{"type":"module","title":"Examples - Geometry.MultiPointZ","doc":"iex> Enum.map(\n    ...>   MultiPointZ.new([\n    ...>     PointZ.new(1, 2, 3),\n    ...>     PointZ.new(3, 4, 5)\n    ...>   ]),\n    ...>   fn [x, _y, _z] -> x end\n    ...> )\n    [1, 3]\n\n    iex> Enum.into([PointZ.new(1, 2, 3)], MultiPointZ.new())\n    %MultiPointZ{points: [[1, 2, 3]]}","ref":"Geometry.MultiPointZ.html#module-examples"},{"type":"function","title":"Geometry.MultiPointZ.new/0","doc":"Creates an empty `MultiPointZ`.","ref":"Geometry.MultiPointZ.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPointZ.new/0","doc":"iex> MultiPointZ.new()\n    %MultiPointZ{points: [], srid: 0}","ref":"Geometry.MultiPointZ.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPointZ.new/2","doc":"Creates a `MultiPointZ` from the given `Geometry.PointZ`s.","ref":"Geometry.MultiPointZ.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPointZ.new/2","doc":"iex> MultiPointZ.new([\n    ...>   PointZ.new(1, 2, 3),\n    ...>   PointZ.new(3, 4, 5)\n    ...> ])\n    %MultiPointZ{points: [[1, 2, 3], [3, 4, 5]], srid: 0}\n\n    iex> MultiPointZ.new([])\n    %MultiPointZ{points: [], srid: 0}","ref":"Geometry.MultiPointZ.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPointZ.t/0","doc":"","ref":"Geometry.MultiPointZ.html#t:t/0"},{"type":"module","title":"Geometry.MultiPointZM","doc":"A set of points from type `Geometry.PointZM`.\n\n`MultiPointZM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPointZM.html"},{"type":"module","title":"Examples - Geometry.MultiPointZM","doc":"iex> Enum.map(\n    ...>   MultiPointZM.new([\n    ...>     PointZM.new(1, 2, 3, 4),\n    ...>     PointZM.new(3, 4, 5, 6)\n    ...>   ]),\n    ...>   fn [x, _y, _z, _m] -> x end\n    ...> )\n    [1, 3]\n\n    iex> Enum.into([PointZM.new(1, 2, 3, 4)], MultiPointZM.new())\n    %MultiPointZM{points: [[1, 2, 3, 4]]}","ref":"Geometry.MultiPointZM.html#module-examples"},{"type":"function","title":"Geometry.MultiPointZM.new/0","doc":"Creates an empty `MultiPointZM`.","ref":"Geometry.MultiPointZM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPointZM.new/0","doc":"iex> MultiPointZM.new()\n    %MultiPointZM{}","ref":"Geometry.MultiPointZM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPointZM.new/2","doc":"Creates a `MultiPointZM` from the given `Geometry.PointZM`s.","ref":"Geometry.MultiPointZM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPointZM.new/2","doc":"iex> MultiPointZM.new([\n    ...>   PointZM.new(1, 2, 3, 4),\n    ...>   PointZM.new(3, 4, 5, 6)\n    ...> ])\n    %MultiPointZM{points: [[1, 2, 3, 4], [3, 4, 5, 6]], srid: 0}\n\n    iex> MultiPointZM.new([])\n    %MultiPointZM{}","ref":"Geometry.MultiPointZM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPointZM.t/0","doc":"","ref":"Geometry.MultiPointZM.html#t:t/0"},{"type":"module","title":"Geometry.MultiPolygonZ","doc":"A set of polygons from type `Geometry.PolygonZ`\n\n`MultiPointZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPolygonZ.html"},{"type":"module","title":"Examples - Geometry.MultiPolygonZ","doc":"iex> Enum.map(\n    ...>   MultiPolygonZ.new([\n    ...>     PolygonZ.new([\n    ...>       LineStringZ.new([\n    ...>         PointZ.new(11, 12, 13),\n    ...>         PointZ.new(11, 22, 23),\n    ...>         PointZ.new(31, 22, 33),\n    ...>         PointZ.new(11, 12, 13)\n    ...>       ]),\n    ...>     ]),\n    ...>     PolygonZ.new([\n    ...>       LineStringZ.new([\n    ...>         PointZ.new(35, 10, 13),\n    ...>         PointZ.new(45, 45, 23),\n    ...>         PointZ.new(10, 20, 33),\n    ...>         PointZ.new(35, 10, 13)\n    ...>       ]),\n    ...>       LineStringZ.new([\n    ...>         PointZ.new(20, 30, 13),\n    ...>         PointZ.new(35, 35, 23),\n    ...>         PointZ.new(30, 20, 33),\n    ...>         PointZ.new(20, 30, 13)\n    ...>       ])\n    ...>     ])\n    ...>   ]),\n    ...>   fn polygon -> length(polygon) == 1 end\n    ...> )\n    [true, false]\n\n    iex> Enum.into(\n    ...>   [\n    ...>     PolygonZ.new([\n    ...>       LineStringZ.new([\n    ...>         PointZ.new(11, 12, 13),\n    ...>         PointZ.new(11, 22, 23),\n    ...>         PointZ.new(31, 22, 33),\n    ...>         PointZ.new(11, 12, 13)\n    ...>       ])\n    ...>     ])\n    ...>   ],\n    ...>   MultiPolygonZ.new())\n    %MultiPolygonZ{\n      polygons: [\n          [\n            [\n              [11, 12, 13],\n              [11, 22, 23],\n              [31, 22, 33],\n              [11, 12, 13]\n            ]\n          ]\n        ],\n      srid: 0\n    }","ref":"Geometry.MultiPolygonZ.html#module-examples"},{"type":"function","title":"Geometry.MultiPolygonZ.new/0","doc":"Creates an empty `MultiPolygonZ`.","ref":"Geometry.MultiPolygonZ.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPolygonZ.new/0","doc":"iex> MultiPolygonZ.new()\n    %MultiPolygonZ{}","ref":"Geometry.MultiPolygonZ.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPolygonZ.new/2","doc":"Creates a `MultiPolygonZ` from the given `Geometry.MultiPolygonZ`s.","ref":"Geometry.MultiPolygonZ.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPolygonZ.new/2","doc":"iex> MultiPolygonZ.new([\n    ...>   PolygonZ.new([\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(6, 2, 3),\n    ...>       PointZ.new(8, 2, 4),\n    ...>       PointZ.new(8, 4, 5),\n    ...>       PointZ.new(6, 2, 3)\n    ...>     ]),\n    ...>   ]),\n    ...>   PolygonZ.new([\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(1, 1, 3),\n    ...>       PointZ.new(9, 1, 4),\n    ...>       PointZ.new(9, 8, 5),\n    ...>       PointZ.new(1, 1, 3)\n    ...>     ]),\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(6, 2, 3),\n    ...>       PointZ.new(7, 2, 4),\n    ...>       PointZ.new(7, 3, 5),\n    ...>       PointZ.new(6, 2, 3)\n    ...>     ])\n    ...>   ])\n    ...> ])\n    %MultiPolygonZ{\n      polygons: [\n          [[[6, 2, 3], [8, 2, 4], [8, 4, 5], [6, 2, 3]]],\n          [\n            [[1, 1, 3], [9, 1, 4], [9, 8, 5], [1, 1, 3]],\n            [[6, 2, 3], [7, 2, 4], [7, 3, 5], [6, 2, 3]]\n          ]\n        ],\n        srid: 0\n    }\n\n    iex> MultiPolygonZ.new([])\n    %MultiPolygonZ{}","ref":"Geometry.MultiPolygonZ.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPolygonZ.t/0","doc":"","ref":"Geometry.MultiPolygonZ.html#t:t/0"},{"type":"module","title":"Geometry.MultiPolygonZM","doc":"A set of polygons from type `Geometry.PolygonZM`\n\n`MultiPointZM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.MultiPolygonZM.html"},{"type":"module","title":"Examples - Geometry.MultiPolygonZM","doc":"iex> Enum.map(\n    ...>   MultiPolygonZM.new([\n    ...>     PolygonZM.new([\n    ...>       LineStringZM.new([\n    ...>         PointZM.new(11, 12, 13, 14),\n    ...>         PointZM.new(11, 22, 23, 24),\n    ...>         PointZM.new(31, 22, 33, 34),\n    ...>         PointZM.new(11, 12, 13, 14)\n    ...>       ]),\n    ...>     ]),\n    ...>     PolygonZM.new([\n    ...>       LineStringZM.new([\n    ...>         PointZM.new(35, 10, 13, 14),\n    ...>         PointZM.new(45, 45, 23, 24),\n    ...>         PointZM.new(10, 20, 33, 34),\n    ...>         PointZM.new(35, 10, 13, 14)\n    ...>       ]),\n    ...>       LineStringZM.new([\n    ...>         PointZM.new(20, 30, 13, 14),\n    ...>         PointZM.new(35, 35, 23, 24),\n    ...>         PointZM.new(30, 20, 33, 34),\n    ...>         PointZM.new(20, 30, 13, 14)\n    ...>       ])\n    ...>     ])\n    ...>   ]),\n    ...>   fn polygon -> length(polygon) == 1 end\n    ...> )\n    [true, false]\n\n    iex> Enum.into(\n    ...>   [\n    ...>     PolygonZM.new([\n    ...>       LineStringZM.new([\n    ...>         PointZM.new(11, 12, 13, 14),\n    ...>         PointZM.new(11, 22, 23, 24),\n    ...>         PointZM.new(31, 22, 33, 34),\n    ...>         PointZM.new(11, 12, 13, 14)\n    ...>       ])\n    ...>     ])\n    ...>   ],\n    ...>   MultiPolygonZM.new())\n    %MultiPolygonZM{\n      polygons: [\n          [\n            [\n              [11, 12, 13, 14],\n              [11, 22, 23, 24],\n              [31, 22, 33, 34],\n              [11, 12, 13, 14]\n            ]\n          ]\n        ],\n      srid: 0\n    }","ref":"Geometry.MultiPolygonZM.html#module-examples"},{"type":"function","title":"Geometry.MultiPolygonZM.new/0","doc":"Creates an empty `MultiPolygonZM`.","ref":"Geometry.MultiPolygonZM.html#new/0"},{"type":"function","title":"Examples - Geometry.MultiPolygonZM.new/0","doc":"iex> MultiPolygonZM.new()\n    %MultiPolygonZM{}","ref":"Geometry.MultiPolygonZM.html#new/0-examples"},{"type":"function","title":"Geometry.MultiPolygonZM.new/2","doc":"Creates a `MultiPolygonZM` from the given `Geometry.MultiPolygonZM`s.","ref":"Geometry.MultiPolygonZM.html#new/2"},{"type":"function","title":"Examples - Geometry.MultiPolygonZM.new/2","doc":"iex> MultiPolygonZM.new([\n    ...>   PolygonZM.new([\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(6, 2, 3, 4),\n    ...>       PointZM.new(8, 2, 4, 5),\n    ...>       PointZM.new(8, 4, 5, 6),\n    ...>       PointZM.new(6, 2, 3, 4)\n    ...>     ]),\n    ...>   ]),\n    ...>   PolygonZM.new([\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(1, 1, 3, 4),\n    ...>       PointZM.new(9, 1, 4, 5),\n    ...>       PointZM.new(9, 8, 5, 6),\n    ...>       PointZM.new(1, 1, 3, 4)\n    ...>     ]),\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(6, 2, 3, 4),\n    ...>       PointZM.new(7, 2, 4, 5),\n    ...>       PointZM.new(7, 3, 5, 6),\n    ...>       PointZM.new(6, 2, 3, 4)\n    ...>     ])\n    ...>   ])\n    ...> ])\n    %MultiPolygonZM{\n      polygons: [\n          [[[6, 2, 3, 4], [8, 2, 4, 5], [8, 4, 5, 6], [6, 2, 3, 4]]],\n          [\n            [[1, 1, 3, 4], [9, 1, 4, 5], [9, 8, 5, 6], [1, 1, 3, 4]],\n            [[6, 2, 3, 4], [7, 2, 4, 5], [7, 3, 5, 6], [6, 2, 3, 4]]\n          ]\n        ],\n        srid: 0\n    }\n\n    iex> MultiPolygonZM.new([])\n    %MultiPolygonZM{}","ref":"Geometry.MultiPolygonZM.html#new/2-examples"},{"type":"type","title":"Geometry.MultiPolygonZM.t/0","doc":"","ref":"Geometry.MultiPolygonZM.html#t:t/0"},{"type":"module","title":"Geometry.GeometryCollection","doc":"A collection set of 2D geometries.\n\n`GeometryCollection` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.GeometryCollection.html"},{"type":"module","title":"Examples - Geometry.GeometryCollection","doc":"iex> Enum.map(\n    ...>   GeometryCollection.new([\n    ...>     Point.new(11, 12),\n    ...>     LineString.new([\n    ...>       Point.new(21, 22),\n    ...>       Point.new(31, 32)\n    ...>     ])\n    ...>   ]),\n    ...>   fn\n    ...>     %Point{} -> :point\n    ...>     %LineString{} -> :line_string\n    ...>   end\n    ...> ) |> Enum.sort()\n    [:line_string, :point]\n\n    iex> Enum.into([Point.new(1, 2)], GeometryCollection.new())\n    %GeometryCollection{geometries: [%Point{coordinates: [1, 2]}]}","ref":"Geometry.GeometryCollection.html#module-examples"},{"type":"function","title":"Geometry.GeometryCollection.new/0","doc":"Creates an empty `GeometryCollection`.","ref":"Geometry.GeometryCollection.html#new/0"},{"type":"function","title":"Examples - Geometry.GeometryCollection.new/0","doc":"iex> GeometryCollection.new()\n    %GeometryCollection{geometries: [], srid: 0}","ref":"Geometry.GeometryCollection.html#new/0-examples"},{"type":"function","title":"Geometry.GeometryCollection.new/2","doc":"Creates an empty `GeometryCollection`.","ref":"Geometry.GeometryCollection.html#new/2"},{"type":"function","title":"Examples - Geometry.GeometryCollection.new/2","doc":"iex> GeometryCollection.new([\n    ...>   Point.new(1, 2),\n    ...>   LineString.new([Point.new(1, 1), Point.new(2, 2)])\n    ...> ])\n    %GeometryCollection{geometries: [\n      %Point{coordinates: [1, 2]},\n      %LineString{path: [[1, 1], [2, 2]]}\n    ],\n    srid: 0}","ref":"Geometry.GeometryCollection.html#new/2-examples"},{"type":"type","title":"Geometry.GeometryCollection.t/0","doc":"","ref":"Geometry.GeometryCollection.html#t:t/0"},{"type":"module","title":"Geometry.GeometryCollectionM","doc":"A collection set of 2D geometries with a measurement.\n\n`GeometryCollectionM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.GeometryCollectionM.html"},{"type":"module","title":"Examples - Geometry.GeometryCollectionM","doc":"iex> Enum.map(\n    ...>   GeometryCollectionM.new([\n    ...>     PointM.new(11, 12, 14),\n    ...>     LineStringM.new([\n    ...>       PointM.new(21, 22, 24),\n    ...>       PointM.new(31, 32, 34)\n    ...>     ])\n    ...>   ]),\n    ...>   fn\n    ...>     %PointM{} -> :point\n    ...>     %LineStringM{} -> :line_string\n    ...>   end\n    ...> ) |> Enum.sort()\n    [:line_string, :point]\n\n    iex> Enum.into([PointM.new(1, 2, 4)], GeometryCollectionM.new())\n    %GeometryCollectionM{geometries: [%PointM{coordinates: [1, 2, 4]}], srid: 0}","ref":"Geometry.GeometryCollectionM.html#module-examples"},{"type":"function","title":"Geometry.GeometryCollectionM.new/0","doc":"Creates an empty `GeometryCollectionM`.","ref":"Geometry.GeometryCollectionM.html#new/0"},{"type":"function","title":"Examples - Geometry.GeometryCollectionM.new/0","doc":"iex> GeometryCollectionM.new()\n    %GeometryCollectionM{}","ref":"Geometry.GeometryCollectionM.html#new/0-examples"},{"type":"function","title":"Geometry.GeometryCollectionM.new/2","doc":"Creates an empty `GeometryCollectionM`.","ref":"Geometry.GeometryCollectionM.html#new/2"},{"type":"function","title":"Examples - Geometry.GeometryCollectionM.new/2","doc":"iex> GeometryCollectionM.new([\n    ...>   PointM.new(1, 2, 4),\n    ...>   LineStringM.new([PointM.new(1, 1, 1), PointM.new(2, 2, 2)])\n    ...> ])\n    %GeometryCollectionM{geometries: [\n      %PointM{coordinates: [1, 2, 4]},\n      %LineStringM{path: [[1, 1, 1], [2, 2, 2]]}\n    ],\n    srid: 0}","ref":"Geometry.GeometryCollectionM.html#new/2-examples"},{"type":"type","title":"Geometry.GeometryCollectionM.t/0","doc":"","ref":"Geometry.GeometryCollectionM.html#t:t/0"},{"type":"module","title":"Geometry.GeometryCollectionZ","doc":"A collection set of 3D geometries.\n\n`GeometryCollectionZ` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.GeometryCollectionZ.html"},{"type":"module","title":"Examples - Geometry.GeometryCollectionZ","doc":"iex> Enum.map(\n    ...>   GeometryCollectionZ.new([\n    ...>     PointZ.new(11, 12, 13),\n    ...>     LineStringZ.new([\n    ...>       PointZ.new(21, 22, 23),\n    ...>       PointZ.new(31, 32, 33)\n    ...>     ])\n    ...>   ]),\n    ...>   fn\n    ...>     %PointZ{} -> :point\n    ...>     %LineStringZ{} -> :line_string\n    ...>   end\n    ...> ) |> Enum.sort()\n    [:line_string, :point]\n\n    iex> Enum.into([PointZ.new(1, 2, 3)], GeometryCollectionZ.new())\n    %GeometryCollectionZ{geometries: [%PointZ{coordinates: [1, 2, 3]}], srid: 0}","ref":"Geometry.GeometryCollectionZ.html#module-examples"},{"type":"function","title":"Geometry.GeometryCollectionZ.new/0","doc":"Creates an empty `GeometryCollectionZ`.","ref":"Geometry.GeometryCollectionZ.html#new/0"},{"type":"function","title":"Examples - Geometry.GeometryCollectionZ.new/0","doc":"iex> GeometryCollectionZ.new()\n    %GeometryCollectionZ{geometries: [], srid: 0}","ref":"Geometry.GeometryCollectionZ.html#new/0-examples"},{"type":"function","title":"Geometry.GeometryCollectionZ.new/2","doc":"Creates an empty `GeometryCollectionZ`.","ref":"Geometry.GeometryCollectionZ.html#new/2"},{"type":"function","title":"Examples - Geometry.GeometryCollectionZ.new/2","doc":"iex> GeometryCollectionZ.new([\n    ...>   PointZ.new(1, 2, 3),\n    ...>   LineStringZ.new([PointZ.new(1, 1, 1), PointZ.new(2, 2, 2)])\n    ...> ])\n    %GeometryCollectionZ{geometries: [\n      %PointZ{coordinates: [1, 2, 3]},\n      %LineStringZ{path: [[1, 1, 1], [2, 2, 2]]}\n    ],\n    srid: 0}","ref":"Geometry.GeometryCollectionZ.html#new/2-examples"},{"type":"type","title":"Geometry.GeometryCollectionZ.t/0","doc":"","ref":"Geometry.GeometryCollectionZ.html#t:t/0"},{"type":"module","title":"Geometry.GeometryCollectionZM","doc":"A collection set of 3D geometries with a measurement.\n\n`GeometryCollectionZM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.GeometryCollectionZM.html"},{"type":"module","title":"Examples - Geometry.GeometryCollectionZM","doc":"iex> Enum.map(\n    ...>   GeometryCollectionZM.new([\n    ...>     PointZM.new(11, 12, 13, 14),\n    ...>     LineStringZM.new([\n    ...>       PointZM.new(21, 22, 23, 24),\n    ...>       PointZM.new(31, 32, 33, 34)\n    ...>     ])\n    ...>   ]),\n    ...>   fn\n    ...>     %PointZM{} -> :point\n    ...>     %LineStringZM{} -> :line_string\n    ...>   end\n    ...> ) |> Enum.sort()\n    [:line_string, :point]\n\n    iex> Enum.into([PointZM.new(1, 2, 3, 4)], GeometryCollectionZM.new())\n    %GeometryCollectionZM{geometries: [%PointZM{coordinates: [1, 2, 3, 4]}], srid: 0}","ref":"Geometry.GeometryCollectionZM.html#module-examples"},{"type":"function","title":"Geometry.GeometryCollectionZM.new/0","doc":"Creates an empty `GeometryCollectionZM`.","ref":"Geometry.GeometryCollectionZM.html#new/0"},{"type":"function","title":"Examples - Geometry.GeometryCollectionZM.new/0","doc":"iex> GeometryCollectionZM.new()\n    %GeometryCollectionZM{}","ref":"Geometry.GeometryCollectionZM.html#new/0-examples"},{"type":"function","title":"Geometry.GeometryCollectionZM.new/2","doc":"Creates an empty `GeometryCollectionZM`.","ref":"Geometry.GeometryCollectionZM.html#new/2"},{"type":"function","title":"Examples - Geometry.GeometryCollectionZM.new/2","doc":"iex> GeometryCollectionZM.new([\n    ...>   PointZM.new(1, 2, 3, 4),\n    ...>   LineStringZM.new([PointZM.new(1, 1, 1, 1), PointZM.new(2, 2, 2, 2)])\n    ...> ])\n    %GeometryCollectionZM{geometries: [\n      %PointZM{coordinates: [1, 2, 3, 4]},\n      %LineStringZM{path: [[1, 1, 1, 1], [2, 2, 2, 2]]}\n    ],\n    srid: 0}","ref":"Geometry.GeometryCollectionZM.html#new/2-examples"},{"type":"type","title":"Geometry.GeometryCollectionZM.t/0","doc":"","ref":"Geometry.GeometryCollectionZM.html#t:t/0"},{"type":"module","title":"Geometry.Feature","doc":"A combination of a `geometry` and `properties`.","ref":"Geometry.Feature.html"},{"type":"function","title":"Geometry.Feature.new/0","doc":"Creates a new empty `Feature`.","ref":"Geometry.Feature.html#new/0"},{"type":"function","title":"Examples - Geometry.Feature.new/0","doc":"iex> Feature.new()\n    %Feature{}","ref":"Geometry.Feature.html#new/0-examples"},{"type":"function","title":"Geometry.Feature.new/1","doc":"Creates a new `Feature`.","ref":"Geometry.Feature.html#new/1"},{"type":"function","title":"Examples - Geometry.Feature.new/1","doc":"iex> Feature.new(\n    ...>   geometry: Point.new(1, 2),\n    ...>   properties: %{facility: :hotel}\n    ...> )\n    %Feature{\n      geometry: %Point{coordinates: [1, 2]},\n      properties: %{facility: :hotel}\n    }","ref":"Geometry.Feature.html#new/1-examples"},{"type":"type","title":"Geometry.Feature.t/0","doc":"","ref":"Geometry.Feature.html#t:t/0"},{"type":"module","title":"Geometry.FeatureCollection","doc":"A collection of `Geometry.Featre`s.\n\n`GeometryCollectionZM` implements the protocols `Enumerable` and `Collectable`.","ref":"Geometry.FeatureCollection.html"},{"type":"module","title":"Examples - Geometry.FeatureCollection","doc":"iex> Enum.filter(\n    ...>   FeatureCollection.new([\n    ...>     Feature.new(\n    ...>       geometry: Point.new(11, 12),\n    ...>       properties: %{\"facility\" => \"Hotel\"}\n    ...>     ),\n    ...>     Feature.new(\n    ...>       geometry: Point.new(55, 55),\n    ...>       properties: %{\"facility\" => \"Tower\"}\n    ...>     )\n    ...>   ]),\n    ...>   fn %Feature{properties: properties} ->\n    ...>     Map.get(properties, \"facility\") == \"Hotel\"\n    ...>   end\n    ...> )\n    [%Feature{geometry: %Point{coordinates: [11, 12]}, properties: %{\"facility\" => \"Hotel\"}}]\n\n    iex> Enum.into(\n    ...>   [Feature.new(geometry: Point.new(5, 1), properties: %{\"area\" => 51})],\n    ...>   FeatureCollection.new([\n    ...>     Feature.new(geometry: Point.new(4, 2), properties: %{\"area\" => 42})\n    ...>   ])\n    ...> )\n    %FeatureCollection{\n      features: [\n          %Feature{geometry: %Point{coordinates: [5, 1]}, properties: %{\"area\" => 51}},\n          %Feature{geometry: %Point{coordinates: [4, 2]}, properties: %{\"area\" => 42}}\n        ]\n    }","ref":"Geometry.FeatureCollection.html#module-examples"},{"type":"function","title":"Geometry.FeatureCollection.new/0","doc":"Creates an empty `FeatureCollection`.","ref":"Geometry.FeatureCollection.html#new/0"},{"type":"function","title":"Examples - Geometry.FeatureCollection.new/0","doc":"iex> FeatureCollection.new()\n    %FeatureCollection{}","ref":"Geometry.FeatureCollection.html#new/0-examples"},{"type":"function","title":"Geometry.FeatureCollection.new/1","doc":"Creates a `FeatureCollection`.","ref":"Geometry.FeatureCollection.html#new/1"},{"type":"function","title":"Examples - Geometry.FeatureCollection.new/1","doc":"iex> FeatureCollection.new([\n    ...>   Feature.new(\n    ...>     geometry: Point.new(1, 2),\n    ...>     properties: %{facility: :hotel}\n    ...>   ),\n    ...>   Feature.new(\n    ...>     geometry: Point.new(3, 4),\n    ...>     properties: %{facility: :school}\n    ...>   )\n    ...> ])\n    %FeatureCollection{features: [\n      %Feature{\n        geometry: %Point{coordinates: [1, 2]},\n        properties: %{facility: :hotel}},\n      %Feature{\n        geometry: %Point{coordinates: [3, 4]},\n        properties: %{facility: :school}}\n    ]}","ref":"Geometry.FeatureCollection.html#new/1-examples"},{"type":"type","title":"Geometry.FeatureCollection.t/0","doc":"","ref":"Geometry.FeatureCollection.html#t:t/0"},{"type":"exception","title":"Geometry.DecodeError","doc":"Raised when the decoding of a geometry fails.","ref":"Geometry.DecodeError.html"},{"type":"type","title":"Geometry.DecodeError.byte_offset/0","doc":"","ref":"Geometry.DecodeError.html#t:byte_offset/0"},{"type":"type","title":"Geometry.DecodeError.line/0","doc":"","ref":"Geometry.DecodeError.html#t:line/0"},{"type":"type","title":"Geometry.DecodeError.t/0","doc":"","ref":"Geometry.DecodeError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.0.0 - 2025/06/30 - Changelog","doc":"+ Require Elixir version `~> 1.15`","ref":"changelog.html#1-0-0-2025-06-30"},{"type":"extras","title":"Breaking changes - Changelog","doc":"+ All geometries now have an SRID field. (Aaron Seigo)\n+ Name improvements. For example the `LineString.coordinates` is now \n  `LineString.path`.  (Aaron Seigo)\n+ Fix: The WKT parser no longer drops leading `0` after a `.` in values.\n  (Aaron Seigo)","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"0.4.0 - 2023/03/12 - Changelog","doc":"","ref":"changelog.html#0-4-0-2023-03-12"},{"type":"extras","title":"Breaking changes - Changelog","doc":"+ Require Elixir version `~> 1.14`\n+ `Geometry.from_wkb/1` excepts just `binary`. A HEX string must be decoded\n  before.\n  ```Elixir\n  iex> wkb = \"00000000013FF0000000000000400199999999999A\"\n  iex> wkb |> Base.decode16!() |> Geometry.from_wkb()\n  {:ok, %Geometry.Point{coordinates: [1.0, 2.2]}}\n  ```\n+ The functions `Geometry.from_ewkb/` and `Geometry.from_ekwt` are added to work\n  with `EWKT`/`EWKB`.\n+ The functions `Geometry.to_wkb/2` and `Geometry.to_ewkb/2` do not have an\n  option to genrate HEX strings. A HEX string can be created with\n  `Base.encode16/1`.","ref":"changelog.html#breaking-changes-1"},{"type":"extras","title":"0.3.2 - 2022/12/11 - Changelog","doc":"+ Refactor `slice` implementations.\n+ Add `recode` package.","ref":"changelog.html#0-3-2-2022-12-11"},{"type":"extras","title":"0.3.1 - 2022/01/30 - Changelog","doc":"+ Use `Base.encode16/1` and `Base.decode16!/1`\n+ Add dep `:prove`\n+ Require Elixir version `~> 1.11`","ref":"changelog.html#0-3-1-2022-01-30"},{"type":"extras","title":"0.3.0 - 2020/11/26 - Changelog","doc":"","ref":"changelog.html#0-3-0-2020-11-26"},{"type":"extras","title":"Breaking changes - Changelog","doc":"+ Change return value for `from_wkb` and `from_wkt`.","ref":"changelog.html#breaking-changes-2"},{"type":"extras","title":"0.2.0 - 2020/11/02 - Changelog","doc":"","ref":"changelog.html#0-2-0-2020-11-02"},{"type":"extras","title":"Breaking changes - Changelog","doc":"+ Add mode (`:hex`/`:binary`) to from_wkb/2 and from_wkb!/2.","ref":"changelog.html#breaking-changes-3"},{"type":"extras","title":"0.1.0 - 2020/10/18 - Changelog","doc":"+ The very first version.","ref":"changelog.html#0-1-0-2020-10-18"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}